
<p align="left">
    <img src="https://raw.githubusercontent.com/Ki-Seki/llmconf/refs/heads/main/assets/logo.png" alt="LLMConf Logo" width="300"/>
</p>

---

[![PyPI](https://img.shields.io/pypi/v/llmconf)](https://pypi.org/project/llmconf/)

LLMConf unifies the loading and generation configurations of various LLM backends (e.g. `openai`, `transformers`, `vllm`), simplifying parameter control for experiments and testing.

> [!Note]
> This project serves as a practical exercise for learning Python project development skills.
